summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvaspixmap_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvaspixmap_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qcanvaspixmap_imp.cpp76
1 files changed, 38 insertions, 38 deletions
diff --git a/kjsembed/qtbindings/qcanvaspixmap_imp.cpp b/kjsembed/qtbindings/qcanvaspixmap_imp.cpp
index 505cdb1f..bc11e8ce 100644
--- a/kjsembed/qtbindings/qcanvaspixmap_imp.cpp
+++ b/kjsembed/qtbindings/qcanvaspixmap_imp.cpp
@@ -23,19 +23,19 @@
*/
namespace KJSEmbed {
-QCanvasPixmapImp::QCanvasPixmapImp( KJS::ExecState *exec, int mid, bool constructor )
+TTQCanvasPixmapImp::TQCanvasPixmapImp( KJS::ExecState *exec, int mid, bool constructor )
: JSProxyImp(exec), id(mid), cons(constructor)
{
}
-QCanvasPixmapImp::~QCanvasPixmapImp()
+TTQCanvasPixmapImp::~TQCanvasPixmapImp()
{
}
/**
* Adds bindings for static methods and enum constants to the specified Object.
*/
-void QCanvasPixmapImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
+void TQCanvasPixmapImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
{
JSProxy::MethodTable methods[] = {
@@ -43,11 +43,11 @@ void QCanvasPixmapImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &obj
};
int idx = 0;
- TQCString lastName;
+ TTQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
- QCanvasPixmapImp *meth = new QCanvasPixmapImp( exec, methods[idx].id );
+ TQCanvasPixmapImp *meth = new TQCanvasPixmapImp( exec, methods[idx].id );
object.put( exec , methods[idx].name, KJS::Object(meth) );
lastName = methods[idx].name;
}
@@ -60,7 +60,7 @@ void QCanvasPixmapImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &obj
/**
* Adds bindings for instance methods to the specified Object.
*/
-void QCanvasPixmapImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
+void TQCanvasPixmapImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
{
JSProxy::MethodTable methods[] = {
@@ -71,11 +71,11 @@ void QCanvasPixmapImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- TQCString lastName;
+ TTQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
- QCanvasPixmapImp *meth = new QCanvasPixmapImp( exec, methods[idx].id );
+ TQCanvasPixmapImp *meth = new TQCanvasPixmapImp( exec, methods[idx].id );
object.put( exec , methods[idx].name, KJS::Object(meth) );
lastName = methods[idx].name;
}
@@ -84,79 +84,79 @@ void QCanvasPixmapImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
* Extract a TQCanvasPixmap pointer from an Object.
*/
-TQCanvasPixmap *QCanvasPixmapImp::toQCanvasPixmap( KJS::Object &self )
+TTQCanvasPixmap *TQCanvasPixmapImp::toTQCanvasPixmap( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- TQObject *obj = ob->object();
+ TTQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<TQCanvasPixmap *>( obj );
+ return dynamic_cast<TTQCanvasPixmap *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "TQCanvasPixmap" )
+ if ( op->typeName() != "TTQCanvasPixmap" )
return 0;
- return op->toNative<TQCanvasPixmap>();
+ return op->toNative<TTQCanvasPixmap>();
}
/**
* Select and invoke the correct constructor.
*/
-KJS::Object QCanvasPixmapImp::construct( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasPixmapImp::construct( KJS::ExecState *exec, const KJS::List &args )
{
switch( id ) {
case Constructor_QCanvasPixmap_1:
- return QCanvasPixmap_1( exec, args );
+ return TQCanvasPixmap_1( exec, args );
break;
case Constructor_QCanvasPixmap_2:
- return QCanvasPixmap_2( exec, args );
+ return TQCanvasPixmap_2( exec, args );
break;
case Constructor_QCanvasPixmap_3:
- return QCanvasPixmap_3( exec, args );
+ return TQCanvasPixmap_3( exec, args );
break;
default:
break;
}
- TQString msg = i18n("QCanvasPixmapCons has no constructor with id '%1'.").arg(id);
+ TTQString msg = i18n("TQCanvasPixmapCons has no constructor with id '%1'.").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
-KJS::Object QCanvasPixmapImp::QCanvasPixmap_1( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasPixmapImp::TQCanvasPixmap_1( KJS::ExecState *exec, const KJS::List &args )
{
- TQString arg0 = extractQString(exec, args, 0);
+ TTQString arg0 = extractTQString(exec, args, 0);
- // We should now create an instance of the TQCanvasPixmap object
+ // We should now create an instance of the TTQCanvasPixmap object
- TQCanvasPixmap *ret = new TQCanvasPixmap(
+ TTQCanvasPixmap *ret = new TTQCanvasPixmap(
arg0 );
return KJS::Object();
}
-KJS::Object QCanvasPixmapImp::QCanvasPixmap_2( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasPixmapImp::TQCanvasPixmap_2( KJS::ExecState *exec, const KJS::List &args )
{
- TQImage arg0 = extractQImage(exec, args, 0);
+ TTQImage arg0 = extractTQImage(exec, args, 0);
- // We should now create an instance of the TQCanvasPixmap object
+ // We should now create an instance of the TTQCanvasPixmap object
- TQCanvasPixmap *ret = new TQCanvasPixmap(
+ TTQCanvasPixmap *ret = new TTQCanvasPixmap(
arg0 );
@@ -164,17 +164,17 @@ KJS::Object QCanvasPixmapImp::QCanvasPixmap_2( KJS::ExecState *exec, const KJS::
}
-KJS::Object QCanvasPixmapImp::QCanvasPixmap_3( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasPixmapImp::TQCanvasPixmap_3( KJS::ExecState *exec, const KJS::List &args )
{
- TQPixmap arg0 = extractQPixmap(exec, args, 0);
+ TTQPixmap arg0 = extractTQPixmap(exec, args, 0);
- TQPoint arg1 = extractQPoint(exec, args, 1);
+ TTQPoint arg1 = extractTQPoint(exec, args, 1);
- // We should now create an instance of the TQCanvasPixmap object
+ // We should now create an instance of the TTQCanvasPixmap object
- TQCanvasPixmap *ret = new TQCanvasPixmap(
+ TTQCanvasPixmap *ret = new TTQCanvasPixmap(
arg0,
arg1 );
@@ -183,9 +183,9 @@ KJS::Object QCanvasPixmapImp::QCanvasPixmap_3( KJS::ExecState *exec, const KJS::
}
-KJS::Value QCanvasPixmapImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
+KJS::Value TQCanvasPixmapImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
{
- instance = QCanvasPixmapImp::toQCanvasPixmap( self );
+ instance = TQCanvasPixmapImp::toTQCanvasPixmap( self );
switch( id ) {
@@ -205,12 +205,12 @@ KJS::Value QCanvasPixmapImp::call( KJS::ExecState *exec, KJS::Object &self, cons
break;
}
- TQString msg = i18n( "QCanvasPixmapImp has no method with id '%1'." ).arg( id );
+ TTQString msg = i18n( "TQCanvasPixmapImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
-KJS::Value QCanvasPixmapImp::offsetX_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasPixmapImp::offsetX_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int ret;
@@ -219,7 +219,7 @@ KJS::Value QCanvasPixmapImp::offsetX_5( KJS::ExecState *exec, KJS::Object &obj,
}
-KJS::Value QCanvasPixmapImp::offsetY_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasPixmapImp::offsetY_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int ret;
@@ -228,7 +228,7 @@ KJS::Value QCanvasPixmapImp::offsetY_6( KJS::ExecState *exec, KJS::Object &obj,
}
-KJS::Value QCanvasPixmapImp::setOffset_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasPixmapImp::setOffset_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int arg0 = extractInt(exec, args, 0);
@@ -84,79 +84,79 @@ void QCanvasPixmapImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a TQCanvasPixmap pointer from an Object.
+ * Extract a TTQCanvasPixmap pointer from an Object.
*/